#code to complete analyses and figure compilation for
  #Andrew W. Child & Barry C. Moore (2019): Total phosphorus analyses: is the convenience 
  #of automated inline-UV digestion robust enough for freshwater nutrient monitoring?,
  #Lake and Reservoir Management, DOI: 10.1080/10402381.2019.1576814

#change working directory to location of data file
#figures will be saved within the working directory automatically as code is run
setwd("")

## SummarySE function code
  ##Source-http://www.cookbook-r.com/Graphs/Plotting_means_and_error_bars_(ggplot2)/#Helper functions
  ## Gives count, mean, standard deviation, standard error of the mean, and confidence interval (default 95%).
  ##   data: a data frame.
  ##   measurevar: the name of a column that contains the variable to be summariezed
  ##   groupvars: a vector containing names of columns that contain grouping variables
  ##   na.rm: a boolean that indicates whether to ignore NA's
  ##   conf.interval: the percent range of the confidence interval (default is 95%)
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}

#Import Data
data<-read.csv("TPComp.csv",header=TRUE)

#calculate difference between methods for samples collected from the surface
trip<-subset(data,samp=="SUR")
trip$diff<-trip$auto120-trip$uv

library(Hmisc)
library(plyr)
describe(trip$diff)
summary(trip$diff)

abs_diff<-abs(trip$diff)
describe(abs_diff)
summary(abs_diff)

wilcox.test(abs_diff)

per_diff<-(abs(trip$diff)/trip$auto120*100)
per_diff
count(per_diff<10)
summary(per_diff)
describe(per_diff)

comp_diff<-trip
comp_diff$per_diff<-per_diff

library(ggplot2)
plot3<-ggplot(comp_diff,aes(x=per_diff))+ 
  geom_histogram(breaks=c(seq(0,100,10)),
                 fill=c("Grey",NA,NA,NA,NA,NA,NA,NA,NA,NA),
                 col=c("Grey","Black","Black","Black","Black",
                       "Black","Black","Black","Black",
                       "Black"))+
  theme_bw(base_size=20,base_family="Helvetica")+
  #set x axis labels
  xlab("Difference Between Methods (%)")+
  #set y axis labels
  ylab("Frequency")+
  #annotate("text",x=5,y=32,label ="n=34")+
  #hide the gridlines
  theme(panel.grid.major=element_blank(),
        panel.grid.minor=element_blank())

tiff("NewFigure2.tiff",width=8,height=8,units="in",res=300)
plot3
dev.off()

#linear model for surface water collected in triplicate
#comparing difference to autoclave

#log-log transform
luv<-log(trip$uv)
lauto<-log(trip$auto120)

#create summary statistics for graphing error bars
diff.sum<-summarySE(trip,measurevar = "diff", groupvars=c("site","type"))
uv.sum<-summarySE(trip,measurevar="uv",groupvars=c("site"))
a120.sum<-summarySE(trip,measurevar="auto120",groupvars=c("site"))

library(ggplot2)
#create data frame using summary statistics for graphing
  #mean and sd
data.comb<-data.frame(diff.sum$type,diff.sum$diff,diff.sum$sd,uv.sum$uv,uv.sum$sd,a120.sum$auto120,a120.sum$sd)
head(data.comb)

plot1<-ggplot(data.comb,aes(y=log(uv.sum.uv),
                            x=log(a120.sum.auto120),
                            shape=diff.sum.type))+
  #geom_errorbarh(aes(xmin=log(a120.sum.auto120)-log(a120.sum.sd),
   #              xmax=log(a120.sum.auto120)+log(a120.sum.sd)))+
  stat_smooth(inherit.aes=F,
              aes(x=log(a120.sum.auto120),y=log(uv.sum.uv)),
              method=lm,
              level=0.95,
              color="black")+
  #geom_errorbar(aes(ymin=log(uv.sum.uv-uv.sum.sd),
   #                 ymax=log(uv.sum.uv+uv.sum.sd)))+
  geom_abline(intercept=0,slope=1,lty=3)+
  geom_point(size=2.5)+
  scale_shape_manual(
    values=c(0,1,2,5),
    breaks=c("Lak","Pon","Res","Riv"),
    labels=c("Lake","Pond","Reservoir","Stream"))+
  labs(shape=NULL)+
  theme_bw(base_size=20,base_family="Helvetica")+
  #format axis
  #ylim(2,6)+
  #xlim(2.9,6)+
  #set x axis labels
  xlab(expression(paste("Log Autoclave Digestion (",mu,"g P/L)")))+
  #set y axis labels
  ylab(expression(paste("Log UV Digestion (",mu,"g P/L)")))+
  #hide the gridlines
  theme(panel.grid.major=element_blank(),
        panel.grid.minor=element_blank())

tiff("Figure1Rev2.tiff",width=8,height=8,units="in",res=300)
plot1
dev.off()
